Documentation
¶
Index ¶
Constants ¶
const ( // Condition IDC key. ConditionIDC = "idc" // Condition location key. ConditionLocation = "location" )
Variables ¶
This section is empty.
Functions ¶
func Evaluate ¶ added in v2.0.1
func Evaluate(ip, hostname string, conditions map[string]string, scopes Scopes, cluster models.SchedulerCluster, log *zap.SugaredLogger) float64
Evaluate the degree of matching between scheduler cluster and dfdaemon.
func FilterSchedulerClusters ¶ added in v2.0.2
func FilterSchedulerClusters(conditions map[string]string, schedulerClusters []models.SchedulerCluster) []models.SchedulerCluster
Filter the scheduler clusters that dfdaemon can be used.
Types ¶
type Scopes ¶
type Scopes struct {
IDC string `mapstructure:"idc"`
Location string `mapstructure:"location"`
CIDRs []string `mapstructure:"cidrs"`
Hostnames []string `mapstructure:"hostnames"`
}
Scheduler cluster scopes.
type Searcher ¶
type Searcher interface {
// FindSchedulerClusters finds scheduler clusters that best matches the evaluation.
FindSchedulerClusters(ctx context.Context, schedulerClusters []models.SchedulerCluster, ip, hostname string,
conditions map[string]string, log *zap.SugaredLogger) ([]models.SchedulerCluster, error)
}
func LoadPlugin ¶
Click to show internal directories.
Click to hide internal directories.