Affected by GO-2025-3963
and 11 other vulnerabilities
GO-2025-3963 : Dragonfly incorrectly handles a task structure’s usedTrac field in d7y.io/dragonfly
GO-2025-3964 : Dragonfly's directories created via os.MkdirAll are not checked for permissions in d7y.io/dragonfly
GO-2025-3965 : Dragonfly doesn't have authentication enabled for some Manager’s endpoints in d7y.io/dragonfly
GO-2025-3966 : Dragonfly's manager makes requests to external endpoints with disabled TLS authentication in d7y.io/dragonfly
GO-2025-3968 : Dragonfly vulnerable to server-side request forgery in d7y.io/dragonfly
GO-2025-3969 : DragonFly's manager generates mTLS certificates for arbitrary IP addresses in d7y.io/dragonfly
GO-2025-3970 : DragonFly vulnerable to panics due to nil pointer dereference when using variables created alongside an error in d7y.io/dragonfly
GO-2025-3971 : DragonFly vulnerable to arbitrary file read and write on a peer machine in d7y.io/dragonfly
GO-2025-3972 : Dragonfly vulnerable to timing attacks against Proxy’s basic authentication in d7y.io/dragonfly
GO-2025-3973 : DragonFly has weak integrity checks for downloaded files in d7y.io/dragonfly
GO-2025-3974 : DragonFly's tiny file download uses hard coded HTTP protocol in d7y.io/dragonfly
GO-2026-4356 : Dragonfly Manager Job API Unauthenticated Access in d7y.io/dragonfly
Discover Packages
d7y.io/dragonfly/v2
pkg
dfnet
package
Version:
v2.1.0-beta.2
Opens a new window with list of versions in this module.
Published: Jul 25, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type NetAddr struct {
Type NetworkType `mapstructure:"type" yaml:"type"`
Addr string `mapstructure:"addr" yaml:"addr"`
}
NetAddr is the definition structure of grpc address,
refer to https://github.com/grpc/grpc/blob/master/doc/naming.md .
String returns the endpoint of network address.
UnmarshalJSON parses the JSON-encoded data and stores the result in NetAddr.
UnmarshalYAML parses the YAML-encoded data and stores the result in NetAddr.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.