Affected by GO-2024-3136
and 12 other vulnerabilities
GO-2024-3136: Dragonfly2 has hard coded cyptographic key in d7y.io/dragonfly
GO-2025-3963: Dragonfly incorrectly handles a task structure’s usedTrac field in d7y.io/dragonfly
GO-2025-3964: Dragonfly's directories created via os.MkdirAll are not checked for permissions in d7y.io/dragonfly
GO-2025-3965: Dragonfly doesn't have authentication enabled for some Manager’s endpoints in d7y.io/dragonfly
GO-2025-3966: Dragonfly's manager makes requests to external endpoints with disabled TLS authentication in d7y.io/dragonfly
GO-2025-3968: Dragonfly vulnerable to server-side request forgery in d7y.io/dragonfly
GO-2025-3969: DragonFly's manager generates mTLS certificates for arbitrary IP addresses in d7y.io/dragonfly
GO-2025-3970: DragonFly vulnerable to panics due to nil pointer dereference when using variables created alongside an error in d7y.io/dragonfly
GO-2025-3971: DragonFly vulnerable to arbitrary file read and write on a peer machine in d7y.io/dragonfly
GO-2025-3972: Dragonfly vulnerable to timing attacks against Proxy’s basic authentication in d7y.io/dragonfly
GO-2025-3973: DragonFly has weak integrity checks for downloaded files in d7y.io/dragonfly
GO-2025-3974: DragonFly's tiny file download uses hard coded HTTP protocol in d7y.io/dragonfly
GO-2026-4356: Dragonfly Manager Job API Unauthenticated Access in d7y.io/dragonfly
package
Version:
v2.0.4-rc.2
Opens a new window with list of versions in this module.
Published: Jun 30, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
var DefaultCacheDir = "/var/cache/dragonfly"
var DefaultWorkHome = "/usr/local/dragonfly"
Dfpath is the interface used for init project path
New returns a new dfpath interface
type Option func(d *dfpath)
Option is a functional option for configuring the dfpath
WithCacheDir set the cache directory
WithDataDir set download data directory
WithLogDir set the log directory
WithWorkHome set the workhome directory
Source Files
¶
Directories
¶
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
Click to show internal directories.
Click to hide internal directories.