Documentation
¶
Index ¶
- Constants
- func IsEnabled(addrs []string) bool
- func MakeApplicationsKeyInManager() string
- func MakeDistributedRateLimiterKeyInManager(key string) string
- func MakeDistributedRateLimiterLockerKeyInManager(key string) string
- func MakeKeyInManager(namespace, id string) string
- func MakeKeyInScheduler(namespace, id string) string
- func MakeNamespaceKeyInManager(namespace string) string
- func MakeNamespaceKeyInScheduler(namespace string) string
- func MakePeerKeyInManager(hostname, ip string) string
- func MakePersistentCacheHostKeyInScheduler(schedulerClusterID uint, hostID string) string
- func MakePersistentCacheHostsInScheduler(schedulerClusterID uint) string
- func MakePersistentCachePeerKeyForPersistentCacheTaskInScheduler(schedulerClusterID uint, peerID string) string
- func MakePersistentCachePeerKeyForPersistentTaskInScheduler(schedulerClusterID uint, peerID string) string
- func MakePersistentCachePeersForPersistentCacheTaskInScheduler(schedulerClusterID uint) string
- func MakePersistentCachePeersForPersistentTaskInScheduler(schedulerClusterID uint) string
- func MakePersistentCachePeersOfPersistentCacheHostInScheduler(schedulerClusterID uint, hostID string) string
- func MakePersistentCachePeersOfPersistentCacheTaskInScheduler(schedulerClusterID uint, taskID string) string
- func MakePersistentCachePeersOfPersistentHostInScheduler(schedulerClusterID uint, hostID string) string
- func MakePersistentCachePeersOfPersistentTaskInScheduler(schedulerClusterID uint, taskID string) string
- func MakePersistentCacheTaskKeyInScheduler(schedulerClusterID uint, taskID string) string
- func MakePersistentCacheTasksInScheduler(schedulerClusterID uint) string
- func MakePersistentHostKeyInScheduler(schedulerClusterID uint, hostID string) string
- func MakePersistentHostsInScheduler(schedulerClusterID uint) string
- func MakePersistentPeersOfPersistentCacheTaskInScheduler(schedulerClusterID uint, taskID string) string
- func MakePersistentPeersOfPersistentTaskInScheduler(schedulerClusterID uint, taskID string) string
- func MakePersistentTaskKeyInScheduler(schedulerClusterID uint, taskID string) string
- func MakePersistentTasksInScheduler(schedulerClusterID uint) string
- func MakeSchedulerKeyInManager(clusterID uint, hostname, ip string) string
- func MakeSchedulersByClusterIDKeyForPeerInManager(schedulerClusterID uint) string
- func MakeSchedulersKeyForPeerInManager(hostname, ip, version string) string
- func MakeSeedPeerKeyInManager(clusterID uint, hostname, ip string) string
- func MakeSeedPeersKeyForPeerInManager(hostname, ip string) string
- func NewRedis(cfg *redis.UniversalOptions) (redis.UniversalClient, error)
- type Proxy
Constants ¶
const ( // SeedPeerNamespace prefix of seed peers namespace cache key. SeedPeersNamespace = "seed-peers" // PeersNamespace prefix of peers namespace cache key. PeersNamespace = "peers" // SchedulersNamespace prefix of schedulers namespace cache key. SchedulersNamespace = "schedulers" // SchedulerClustersNamespace prefix of scheduler clusters namespace cache key. SchedulerClustersNamespace = "scheduler-clusters" // PersistentTasksNamespace prefix of tasks namespace cache key. PersistentTasksNamespace = "persistent-tasks" // PersistentHostsNamespace prefix of persistent cache hosts namespace cache key. PersistentHostsNamespace = "persistent-hosts" // PersistentCachePeersForPersistentTaskNamespace prefix of persistent cache peers namespace cache key for persistent task. PersistentCachePeersForPersistentTaskNamespace = "persistent-cache-peers-for-persistent-task" // PersistentPeersForPersistentTaskNamespace prefix of persistent peers namespace cache key for persistent task. PersistentPeersForPersistentTaskNamespace = "persistent-peers-for-persistent-task" // PersistentCacheTasksNamespace prefix of tasks namespace cache key. PersistentCacheTasksNamespace = "persistent-cache-tasks" // PersistentCacheHostsNamespace prefix of persistent cache hosts namespace cache key. PersistentCacheHostsNamespace = "persistent-cache-hosts" // PersistentCachePeersForPersistentCacheTaskNamespace prefix of persistent cache peers namespace cache key for persistent cache task. PersistentCachePeersForPersistentCacheTaskNamespace = "persistent-cache-peers-for-persistent-cache-task" // PersistentPeersForPersistentCacheTaskNamespace prefix of persistent peers namespace cache key for persistent cache task. PersistentPeersForPersistentCacheTaskNamespace = "persistent-peers-for-persistent-cache-task" // ApplicationsNamespace prefix of applications namespace cache key. ApplicationsNamespace = "applications" // RateLimitersNamespace prefix of rate limiters namespace cache key. RateLimitersNamespace = "rate-limiters" )
const (
// KeySeparator is the separator of redis key.
KeySeparator = ":"
)
Variables ¶
This section is empty.
Functions ¶
func MakeApplicationsKeyInManager ¶
func MakeApplicationsKeyInManager() string
MakeApplicationsKeyInManager make applications key in manager.
func MakeDistributedRateLimiterKeyInManager ¶ added in v2.1.63
MakeSchedulerClusterKeyInManager make distributed rate limiter key in manager.
func MakeDistributedRateLimiterLockerKeyInManager ¶ added in v2.1.63
MakeSchedulerClusterKeyInManager make locker key of distributed rate limiter in manager.
func MakeKeyInManager ¶
MakeKeyInManager make key in manager.
func MakeKeyInScheduler ¶
MakeKeyInScheduler make key in scheduler.
func MakeNamespaceKeyInManager ¶
MakeNamespaceKeyInManager make namespace key in manager.
func MakeNamespaceKeyInScheduler ¶
MakeNamespaceKeyInScheduler make namespace key in scheduler.
func MakePeerKeyInManager ¶
MakePeerKeyInManager make peer key in manager.
func MakePersistentCacheHostKeyInScheduler ¶ added in v2.1.60
MakePersistentCacheHostKeyInScheduler make persistent cache host key in scheduler.
func MakePersistentCacheHostsInScheduler ¶ added in v2.1.60
MakePersistentCacheHostsInScheduler make persistent cache hosts in scheduler.
func MakePersistentCachePeerKeyForPersistentCacheTaskInScheduler ¶ added in v2.4.0
func MakePersistentCachePeerKeyForPersistentCacheTaskInScheduler(schedulerClusterID uint, peerID string) string
MakePersistentCachePeerKeyForPersistentCacheTaskInScheduler make persistent cache peer key in scheduler for persistent cache task.
func MakePersistentCachePeerKeyForPersistentTaskInScheduler ¶ added in v2.4.0
func MakePersistentCachePeerKeyForPersistentTaskInScheduler(schedulerClusterID uint, peerID string) string
MakePersistentCachePeerKeyForPersistentTaskInScheduler make persistent cache peer key in scheduler for persistent task.
func MakePersistentCachePeersForPersistentCacheTaskInScheduler ¶ added in v2.4.0
MakePersistentCachePeersForPersistentCacheTaskInScheduler make persistent cache peers for persistent cache task in scheduler.
func MakePersistentCachePeersForPersistentTaskInScheduler ¶ added in v2.4.0
MakePersistentCachePeersForPersistentTaskInScheduler make persistent cache peers for persistent task in scheduler.
func MakePersistentCachePeersOfPersistentCacheHostInScheduler ¶ added in v2.1.62
func MakePersistentCachePeersOfPersistentCacheHostInScheduler(schedulerClusterID uint, hostID string) string
MakePersistentCachePeersOfPersistentCacheHostInScheduler make persistent cache peers of persistent cache host in scheduler.
func MakePersistentCachePeersOfPersistentCacheTaskInScheduler ¶ added in v2.1.62
func MakePersistentCachePeersOfPersistentCacheTaskInScheduler(schedulerClusterID uint, taskID string) string
MakePersistentCachePeersOfPersistentCacheTaskInScheduler make persistent cache peers of persistent cache task in scheduler.
func MakePersistentCachePeersOfPersistentHostInScheduler ¶ added in v2.4.0
func MakePersistentCachePeersOfPersistentHostInScheduler(schedulerClusterID uint, hostID string) string
MakePersistentCachePeersOfPersistentHostInScheduler make persistent cache peers of persistent host in scheduler.
func MakePersistentCachePeersOfPersistentTaskInScheduler ¶ added in v2.4.0
func MakePersistentCachePeersOfPersistentTaskInScheduler(schedulerClusterID uint, taskID string) string
MakePersistentCachePeersOfPersistentTaskInScheduler make persistent cache peers of persistent task in scheduler.
func MakePersistentCacheTaskKeyInScheduler ¶ added in v2.1.60
MakePersistentCacheTaskKeyInScheduler make persistent cache task key in scheduler.
func MakePersistentCacheTasksInScheduler ¶ added in v2.1.60
MakePersistentCacheTasksInScheduler make persistent cache tasks in scheduler.
func MakePersistentHostKeyInScheduler ¶ added in v2.4.0
MakePersistentHostKeyInScheduler make persistent host key in scheduler.
func MakePersistentHostsInScheduler ¶ added in v2.4.0
MakePersistentHostsInScheduler make persistent hosts in scheduler.
func MakePersistentPeersOfPersistentCacheTaskInScheduler ¶ added in v2.1.63
func MakePersistentPeersOfPersistentCacheTaskInScheduler(schedulerClusterID uint, taskID string) string
MakePersistentPeersOfPersistentCacheTaskInScheduler make persistent peers of persistent cache task in scheduler.
func MakePersistentPeersOfPersistentTaskInScheduler ¶ added in v2.4.0
MakePersistentPeersOfPersistentTaskInScheduler make persistent peers of persistent task in scheduler.
func MakePersistentTaskKeyInScheduler ¶ added in v2.4.0
MakePersistentTaskKeyInScheduler make persistent task key in scheduler.
func MakePersistentTasksInScheduler ¶ added in v2.4.0
MakePersistentTasksInScheduler make persistent tasks in scheduler.
func MakeSchedulerKeyInManager ¶
MakeSchedulerKeyInManager make scheduler key in manager.
func MakeSchedulersByClusterIDKeyForPeerInManager ¶ added in v2.3.2
MakeSchedulersByClusterIDKeyForPeerInManager make schedulers by cluster ID key for peer in manager.
func MakeSchedulersKeyForPeerInManager ¶
MakeSchedulersKeyForPeerInManager make schedulers key for peer in manager.
func MakeSeedPeerKeyInManager ¶
MakeSeedPeerKeyInManager make seed peer key in manager.
func MakeSeedPeersKeyForPeerInManager ¶ added in v2.1.21
MakeSeedPeersKeyForPeerInManager make seed peers key for peer in manager.
func NewRedis ¶
func NewRedis(cfg *redis.UniversalOptions) (redis.UniversalClient, error)
NewRedis returns a new redis client.