mocks

package
v2.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 8, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockPool added in v2.3.4

type MockPool struct {
	// contains filtered or unexported fields
}

MockPool is a mock of Pool interface.

func NewMockPool added in v2.3.4

func NewMockPool(ctrl *gomock.Controller) *MockPool

NewMockPool creates a new mock instance.

func (*MockPool) EXPECT added in v2.3.4

func (m *MockPool) EXPECT() *MockPoolMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockPool) Get added in v2.3.4

func (m *MockPool) Get(target string, opts ...grpc.DialOption) (client.V2, error)

Get mocks base method.

func (*MockPool) Serve added in v2.3.4

func (m *MockPool) Serve()

Serve mocks base method.

func (*MockPool) Stop added in v2.3.4

func (m *MockPool) Stop()

Stop mocks base method.

type MockPoolMockRecorder added in v2.3.4

type MockPoolMockRecorder struct {
	// contains filtered or unexported fields
}

MockPoolMockRecorder is the mock recorder for MockPool.

func (*MockPoolMockRecorder) Get added in v2.3.4

func (mr *MockPoolMockRecorder) Get(target any, opts ...any) *gomock.Call

Get indicates an expected call of Get.

func (*MockPoolMockRecorder) Serve added in v2.3.4

func (mr *MockPoolMockRecorder) Serve() *gomock.Call

Serve indicates an expected call of Serve.

func (*MockPoolMockRecorder) Stop added in v2.3.4

func (mr *MockPoolMockRecorder) Stop() *gomock.Call

Stop indicates an expected call of Stop.

type MockV1 added in v2.0.9

type MockV1 struct {
	// contains filtered or unexported fields
}

MockV1 is a mock of V1 interface.

func NewMockV1 added in v2.0.9

func NewMockV1(ctrl *gomock.Controller) *MockV1

NewMockV1 creates a new mock instance.

func (*MockV1) CheckHealth added in v2.0.9

func (m *MockV1) CheckHealth(arg0 context.Context, arg1 ...grpc.CallOption) error

CheckHealth mocks base method.

func (*MockV1) Close added in v2.0.9

func (m *MockV1) Close() error

Close mocks base method.

func (*MockV1) DeleteTask added in v2.0.9

func (m *MockV1) DeleteTask(arg0 context.Context, arg1 *dfdaemon.DeleteTaskRequest, arg2 ...grpc.CallOption) error

DeleteTask mocks base method.

func (*MockV1) Download added in v2.0.9

Download mocks base method.

func (*MockV1) EXPECT added in v2.0.9

func (m *MockV1) EXPECT() *MockV1MockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockV1) ExportTask added in v2.0.9

func (m *MockV1) ExportTask(arg0 context.Context, arg1 *dfdaemon.ExportTaskRequest, arg2 ...grpc.CallOption) error

ExportTask mocks base method.

func (*MockV1) GetPieceTasks added in v2.0.9

func (m *MockV1) GetPieceTasks(arg0 context.Context, arg1 *common.PieceTaskRequest, arg2 ...grpc.CallOption) (*common.PiecePacket, error)

GetPieceTasks mocks base method.

func (*MockV1) ImportTask added in v2.0.9

func (m *MockV1) ImportTask(arg0 context.Context, arg1 *dfdaemon.ImportTaskRequest, arg2 ...grpc.CallOption) error

ImportTask mocks base method.

func (*MockV1) LeaveHost added in v2.1.32

func (m *MockV1) LeaveHost(arg0 context.Context, arg1 ...grpc.CallOption) error

LeaveHost mocks base method.

func (*MockV1) PeerExchange added in v2.1.41

func (m *MockV1) PeerExchange(ctx context.Context, opts ...grpc.CallOption) (dfdaemon.Daemon_PeerExchangeClient, error)

PeerExchange mocks base method.

func (*MockV1) StatTask added in v2.0.9

func (m *MockV1) StatTask(arg0 context.Context, arg1 *dfdaemon.StatTaskRequest, arg2 ...grpc.CallOption) error

StatTask mocks base method.

func (*MockV1) SyncPieceTasks added in v2.0.9

SyncPieceTasks mocks base method.

type MockV1MockRecorder added in v2.0.9

type MockV1MockRecorder struct {
	// contains filtered or unexported fields
}

MockV1MockRecorder is the mock recorder for MockV1.

func (*MockV1MockRecorder) CheckHealth added in v2.0.9

func (mr *MockV1MockRecorder) CheckHealth(arg0 any, arg1 ...any) *gomock.Call

CheckHealth indicates an expected call of CheckHealth.

func (*MockV1MockRecorder) Close added in v2.0.9

func (mr *MockV1MockRecorder) Close() *gomock.Call

Close indicates an expected call of Close.

func (*MockV1MockRecorder) DeleteTask added in v2.0.9

func (mr *MockV1MockRecorder) DeleteTask(arg0, arg1 any, arg2 ...any) *gomock.Call

DeleteTask indicates an expected call of DeleteTask.

func (*MockV1MockRecorder) Download added in v2.0.9

func (mr *MockV1MockRecorder) Download(arg0, arg1 any, arg2 ...any) *gomock.Call

Download indicates an expected call of Download.

func (*MockV1MockRecorder) ExportTask added in v2.0.9

func (mr *MockV1MockRecorder) ExportTask(arg0, arg1 any, arg2 ...any) *gomock.Call

ExportTask indicates an expected call of ExportTask.

func (*MockV1MockRecorder) GetPieceTasks added in v2.0.9

func (mr *MockV1MockRecorder) GetPieceTasks(arg0, arg1 any, arg2 ...any) *gomock.Call

GetPieceTasks indicates an expected call of GetPieceTasks.

func (*MockV1MockRecorder) ImportTask added in v2.0.9

func (mr *MockV1MockRecorder) ImportTask(arg0, arg1 any, arg2 ...any) *gomock.Call

ImportTask indicates an expected call of ImportTask.

func (*MockV1MockRecorder) LeaveHost added in v2.1.32

func (mr *MockV1MockRecorder) LeaveHost(arg0 any, arg1 ...any) *gomock.Call

LeaveHost indicates an expected call of LeaveHost.

func (*MockV1MockRecorder) PeerExchange added in v2.1.41

func (mr *MockV1MockRecorder) PeerExchange(ctx any, opts ...any) *gomock.Call

PeerExchange indicates an expected call of PeerExchange.

func (*MockV1MockRecorder) StatTask added in v2.0.9

func (mr *MockV1MockRecorder) StatTask(arg0, arg1 any, arg2 ...any) *gomock.Call

StatTask indicates an expected call of StatTask.

func (*MockV1MockRecorder) SyncPieceTasks added in v2.0.9

func (mr *MockV1MockRecorder) SyncPieceTasks(arg0, arg1 any, arg2 ...any) *gomock.Call

SyncPieceTasks indicates an expected call of SyncPieceTasks.

type MockV2 added in v2.0.9

type MockV2 struct {
	// contains filtered or unexported fields
}

MockV2 is a mock of V2 interface.

func NewMockV2 added in v2.0.9

func NewMockV2(ctrl *gomock.Controller) *MockV2

NewMockV2 creates a new mock instance.

func (*MockV2) Close added in v2.0.9

func (m *MockV2) Close() error

Close mocks base method.

func (*MockV2) DeletePersistentCacheTask added in v2.1.60

func (m *MockV2) DeletePersistentCacheTask(arg0 context.Context, arg1 *dfdaemon.DeletePersistentCacheTaskRequest, arg2 ...grpc.CallOption) error

DeletePersistentCacheTask mocks base method.

func (*MockV2) DeletePersistentTask added in v2.4.0

func (m *MockV2) DeletePersistentTask(arg0 context.Context, arg1 *dfdaemon.DeletePersistentTaskRequest, arg2 ...grpc.CallOption) error

DeletePersistentTask mocks base method.

func (*MockV2) DeleteTask added in v2.0.9

func (m *MockV2) DeleteTask(arg0 context.Context, arg1 *dfdaemon.DeleteTaskRequest, arg2 ...grpc.CallOption) error

DeleteTask mocks base method.

func (*MockV2) DownloadPersistentCacheTask added in v2.1.60

DownloadPersistentCacheTask mocks base method.

func (*MockV2) DownloadPersistentTask added in v2.4.0

DownloadPersistentTask mocks base method.

func (*MockV2) DownloadPiece added in v2.1.24

DownloadPiece mocks base method.

func (*MockV2) DownloadTask added in v2.0.9

DownloadTask mocks base method.

func (*MockV2) EXPECT added in v2.0.9

func (m *MockV2) EXPECT() *MockV2MockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockV2) ListTaskEntries added in v2.3.4

ListTaskEntries mocks base method.

func (*MockV2) StatLocalTask added in v2.4.0

StatLocalTask mocks base method.

func (*MockV2) StatPersistentCacheTask added in v2.1.60

func (m *MockV2) StatPersistentCacheTask(arg0 context.Context, arg1 *dfdaemon.StatPersistentCacheTaskRequest, arg2 ...grpc.CallOption) (*common.PersistentCacheTask, error)

StatPersistentCacheTask mocks base method.

func (*MockV2) StatPersistentTask added in v2.4.0

func (m *MockV2) StatPersistentTask(arg0 context.Context, arg1 *dfdaemon.StatPersistentTaskRequest, arg2 ...grpc.CallOption) (*common.PersistentTask, error)

StatPersistentTask mocks base method.

func (*MockV2) StatTask added in v2.0.9

func (m *MockV2) StatTask(arg0 context.Context, arg1 *dfdaemon.StatTaskRequest, arg2 ...grpc.CallOption) (*common.Task, error)

StatTask mocks base method.

func (*MockV2) SyncPieces added in v2.0.9

SyncPieces mocks base method.

func (*MockV2) UpdatePersistentCacheTask added in v2.2.1

func (m *MockV2) UpdatePersistentCacheTask(arg0 context.Context, arg1 *dfdaemon.UpdatePersistentCacheTaskRequest, arg2 ...grpc.CallOption) error

UpdatePersistentCacheTask mocks base method.

func (*MockV2) UpdatePersistentTask added in v2.4.0

func (m *MockV2) UpdatePersistentTask(arg0 context.Context, arg1 *dfdaemon.UpdatePersistentTaskRequest, arg2 ...grpc.CallOption) error

UpdatePersistentTask mocks base method.

type MockV2MockRecorder added in v2.0.9

type MockV2MockRecorder struct {
	// contains filtered or unexported fields
}

MockV2MockRecorder is the mock recorder for MockV2.

func (*MockV2MockRecorder) Close added in v2.0.9

func (mr *MockV2MockRecorder) Close() *gomock.Call

Close indicates an expected call of Close.

func (*MockV2MockRecorder) DeletePersistentCacheTask added in v2.1.60

func (mr *MockV2MockRecorder) DeletePersistentCacheTask(arg0, arg1 any, arg2 ...any) *gomock.Call

DeletePersistentCacheTask indicates an expected call of DeletePersistentCacheTask.

func (*MockV2MockRecorder) DeletePersistentTask added in v2.4.0

func (mr *MockV2MockRecorder) DeletePersistentTask(arg0, arg1 any, arg2 ...any) *gomock.Call

DeletePersistentTask indicates an expected call of DeletePersistentTask.

func (*MockV2MockRecorder) DeleteTask added in v2.0.9

func (mr *MockV2MockRecorder) DeleteTask(arg0, arg1 any, arg2 ...any) *gomock.Call

DeleteTask indicates an expected call of DeleteTask.

func (*MockV2MockRecorder) DownloadPersistentCacheTask added in v2.1.60

func (mr *MockV2MockRecorder) DownloadPersistentCacheTask(arg0, arg1 any, arg2 ...any) *gomock.Call

DownloadPersistentCacheTask indicates an expected call of DownloadPersistentCacheTask.

func (*MockV2MockRecorder) DownloadPersistentTask added in v2.4.0

func (mr *MockV2MockRecorder) DownloadPersistentTask(arg0, arg1 any, arg2 ...any) *gomock.Call

DownloadPersistentTask indicates an expected call of DownloadPersistentTask.

func (*MockV2MockRecorder) DownloadPiece added in v2.1.24

func (mr *MockV2MockRecorder) DownloadPiece(arg0, arg1 any, arg2 ...any) *gomock.Call

DownloadPiece indicates an expected call of DownloadPiece.

func (*MockV2MockRecorder) DownloadTask added in v2.0.9

func (mr *MockV2MockRecorder) DownloadTask(arg0, arg1, arg2 any, arg3 ...any) *gomock.Call

DownloadTask indicates an expected call of DownloadTask.

func (*MockV2MockRecorder) ListTaskEntries added in v2.3.4

func (mr *MockV2MockRecorder) ListTaskEntries(arg0, arg1 any, arg2 ...any) *gomock.Call

ListTaskEntries indicates an expected call of ListTaskEntries.

func (*MockV2MockRecorder) StatLocalTask added in v2.4.0

func (mr *MockV2MockRecorder) StatLocalTask(arg0, arg1 any, arg2 ...any) *gomock.Call

StatLocalTask indicates an expected call of StatLocalTask.

func (*MockV2MockRecorder) StatPersistentCacheTask added in v2.1.60

func (mr *MockV2MockRecorder) StatPersistentCacheTask(arg0, arg1 any, arg2 ...any) *gomock.Call

StatPersistentCacheTask indicates an expected call of StatPersistentCacheTask.

func (*MockV2MockRecorder) StatPersistentTask added in v2.4.0

func (mr *MockV2MockRecorder) StatPersistentTask(arg0, arg1 any, arg2 ...any) *gomock.Call

StatPersistentTask indicates an expected call of StatPersistentTask.

func (*MockV2MockRecorder) StatTask added in v2.0.9

func (mr *MockV2MockRecorder) StatTask(arg0, arg1 any, arg2 ...any) *gomock.Call

StatTask indicates an expected call of StatTask.

func (*MockV2MockRecorder) SyncPieces added in v2.0.9

func (mr *MockV2MockRecorder) SyncPieces(arg0, arg1 any, arg2 ...any) *gomock.Call

SyncPieces indicates an expected call of SyncPieces.

func (*MockV2MockRecorder) UpdatePersistentCacheTask added in v2.2.1

func (mr *MockV2MockRecorder) UpdatePersistentCacheTask(arg0, arg1 any, arg2 ...any) *gomock.Call

UpdatePersistentCacheTask indicates an expected call of UpdatePersistentCacheTask.

func (*MockV2MockRecorder) UpdatePersistentTask added in v2.4.0

func (mr *MockV2MockRecorder) UpdatePersistentTask(arg0, arg1 any, arg2 ...any) *gomock.Call

UpdatePersistentTask indicates an expected call of UpdatePersistentTask.

Jump to